@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: forms.py 11237 2018-10-04 12:45:49Z Lavender $
+# $Id: forms.py 12819 2021-03-30 02:12:19Z Becca $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,14 +11,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2018-10-04 20:45:49 +0800 (Thu, 04 Oct 2018) $
-# $Revision: 11237 $
+# $Author: Becca $ (last)
+# $Date: 2021-03-30 10:12:19 +0800 (Tue, 30 Mar 2021) $
+# $Revision: 12819 $
 
 from django import forms
 from django.utils.translation import ugettext_lazy as _
 
-from Zephyrus.cms_oscar.models import OscarFeatured, OscarLatest
+from Zephyrus.cms_oscar.models import OscarFeatured, OscarLatest, OscarBestSellerForm
 from oscar.core.loading import get_model
 
 Product = get_model('catalogue', 'Product')
@@ -95,3 +95,32 @@ class OscarLatestForm(forms.ModelForm):
     class Meta:
         model = OscarLatest
         exclude = ['tag']
+
+class OscarBestSellerForm(forms.ModelForm):
+    if hasTags:
+        tag = forms.MultipleChoiceField(
+            choices=tagList,
+            required=False,
+            help_text=_(
+                "If no choice. It will not filter product by tag.")
+        )
+    
+    def __init__(self, *args, **kwargs): 
+        super(OscarBestSellerForm, self) .__init__(*args, **kwargs) 
+        if hasTags:
+            if self.instance.tag:
+                self.fields['tag'].initial = self.instance.tag.split(",")
+
+    def save(self, commit=True):
+        obj = super(OscarBestSellerForm, self).save(commit=commit)
+
+        if hasTags:
+            tags = ",".join(self.cleaned_data.get('tag', []))
+            obj.tag = tags
+            obj.save()
+            
+        return obj
+
+    class Meta:
+        model = OscarBestSeller
+        exclude = ['tag']
